@@ -1,3 +1,4 @@
+
 from .handler import RequestHandler
 from .tables import *
 from .utils import *
@@ -8,12 +9,16 @@ class SqlApiError(Exception):
 
 
 class API(RequestHandler):
-    def __init__(self, db_path):
+    def __init__(self, db_path=None):
         """
         :param db_path: The path to the file
         :type db_path: str
         """
-        RequestHandler.__init__(self, db_path)
+
+        self._active = False
+        if db_path:
+            RequestHandler.__init__(self, db_path)
+            self._active = True
         try:
             self.data_bases = globals()['data_bases']
         except KeyError:
@@ -34,6 +39,8 @@ class API(RequestHandler):
         :param table_classes_: Object or objects received by filter function
         :return: Successfully
         """
+
+        self._check_active()
         table_classes = table_classes_ if len(table_classes) == 0 else table_classes
         if len(table_classes) != 0:
             for table in table_classes:
@@ -49,7 +56,7 @@ class API(RequestHandler):
         else:
             raise SqlApiError('Not transferred to the pill classes')
 
-    def select(self, table_name):
+    def _select(self, table_name):
         return self.execute("SELECT * FROM '%s'" % table_name.lower())
 
     def filter(self, table_name, return_type='visual', return_list=False, where_=(), **where):
@@ -66,9 +73,11 @@ class API(RequestHandler):
         :param where: Filtering options
         :return: list or object
         """
+
+        self._check_active()
         where_ = {} if type(where_).__name__ != 'dict' else where_
         table_name = table_name.lower()
-        obj = self.get_obj(table_name)
+        obj = self._get_obj(table_name)
         obj_fields = get_fields(obj)
         condition = []
         where = where_ if len(where) == 0 else where
@@ -94,7 +103,7 @@ class API(RequestHandler):
             data = self.execute("SELECT * FROM '%s' WHERE %s" % (table_name, ' and '.join(condition)))
 
         else:
-            data = self.select(table_name)
+            data = self._select(table_name)
 
         if len(data) == 0:
             return
@@ -120,8 +129,10 @@ class API(RequestHandler):
         :param values: Values of the columns
         :return: Successfully
         """
+
+        self._check_active()
         table_name = table_name.lower()
-        obj = self.get_obj(table_name)
+        obj = self._get_obj(table_name)
         obj_fields = get_fields(obj)
         fields = [i for i in obj_fields]
 
@@ -147,11 +158,12 @@ class API(RequestHandler):
         :param table_name: Table name
         :param field_name: Field name
         :param start_value: The starting value of this field
-        :return:
+        :return: Successfully
         """
 
+        self._check_active()
         table_name = table_name.lower()
-        obj = self.get_obj(table_name)
+        obj = self._get_obj(table_name)
         obj_fields = get_fields(obj)
 
         if field_name not in obj_fields:
@@ -164,8 +176,15 @@ class API(RequestHandler):
         return 'Successfully'
 
     def get_class(self, table_name, data):
-        obj = self.get_obj(table_name.lower())
-        types = vars(self.get_obj(table_name.lower()))
+        """
+        Returns table class object based on its data
+        :param table_name: Table name
+        :param data: Data obtained by metod Filter
+        :return: Table class
+        """
+
+        obj = self._get_obj(table_name.lower())
+        types = vars(self._get_obj(table_name.lower()))
         fields = get_fields(obj)
         exec("obj.id = {}".format(data[0]))
         data = data[1:]
@@ -184,6 +203,7 @@ class API(RequestHandler):
         :return: Successfully
         """
 
+        self._check_active()
         for table in self.data_bases:
             fields = ''
             table_name = type(table).__name__.lower()
@@ -199,8 +219,19 @@ class API(RequestHandler):
             self._cursor.execute(request)
         return 'Successfully'
 
+    def get_cursor(self):
+        """
+        :return: Cursor object
+        """
+        self._check_active()
+        return self._cursor
+
+    def _check_active(self):
+        if not self._active:
+            raise SqlApiError('The database file not inital')
+
     @staticmethod
-    def get_obj(table_name):
+    def _get_obj(table_name):
         table = get(table_name.lower())
         if table:
             return table
